codedelegate — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- delegates »

# codedelegate

class `camelot.view.controls.delegates.codedelegate.` `CodeDelegate`(parent=None, parts=[], separator=u'.', **kwargs)

  Field attributes supported by the delegate :

  > - parts
  > - separator

  By default, creates a CodeEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - parts
  > - editable
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- delegates »

Comments
blog comments powered by Disqus